Notebooks
========================================================================================

Getting Started
-----------------------------------------------------------------------------------------

We recommend that new users start with the following notebooks to get a basic understanding
of the TDAstro package and how to use it.

.. toctree::
    :maxdepth: 1

    Introduction <notebooks/introduction>
    Building Simple Models <notebooks/technical_overview>
    Sampling Model Parameters <notebooks/sampling>


Technical Details
-----------------------------------------------------------------------------------------

The following notebooks provide more in-depth technical deep dives into specific 
features and models of the TDAstro package.

.. toctree::
    :maxdepth: 1

    Using Rubin OpSims in Simulations <notebooks/opsim_notebook>
    Passband Demo <notebooks/passband-demo>
    Adding New Source Types <notebooks/adding_sources>
    Adding New Effect Types <notebooks/adding_effects>
    Lightcurve Source Demo <notebooks/lightcurve_source_demo>
    Advanced Sampling Techniques <notebooks/advanced_sampling>
    PZFlow Source Demo <notebooks/using_pzflow>


Example Simulations
-----------------------------------------------------------------------------------------

The following notebooks provide example simulations using the TDAstro package.

.. toctree::
    :maxdepth: 1

    PLAsTiCC SNIa <notebooks/pre_executed/plasticc_snia>
    Resampling LCLIB <notebooks/pre_executed/lclib_example>
